@@ -6,7 +6,6 @@ OC.L10N.register(
     "Cancel" : "Cancel",
     "Required" : "Vereis",
     "Delete" : "Skrap",
-    "Uploading …" : "Laai tans op …",
     "Other" : "Ander",
     "Set expiration date" : "Stel vervaldatum",
     "Group" : "Groep",
@@ -29,6 +28,7 @@ OC.L10N.register(
     "Color" : "Kleur",
     "Text" : "Teks",
     "Phone number" : "Foonnommer",
-    "Email address" : "E-posadres"
+    "Email address" : "E-posadres",
+    "Uploading …" : "Laai tans op …"
 },
 "nplurals=2; plural=(n != 1);");
